@@ -33,10 +33,14 @@ from ._core import (
     complex_array_to_int16_complex,
     int16_complex_array_to_complex,
     iterate_extended_structure,
+    iterate_extended_structure_values,
     load_record,
     open_record,
     save_record,
     save_record_to_h5,
+    zip3_extended_structures,
+    zip_extended_structures,
 )
 from ._core_ext import _ReplayingClient, _StopReplay
-from ._perf_calc import _PerformanceCalc
+from ._perf_calc import _SensorPerformanceCalc, _SessionPerformanceCalc
+from ._rate_calc import _RateCalculator, _RateStats
