@@ -4,6 +4,7 @@
 from __future__ import annotations
 
 import enum
+import itertools
 import json
 import re
 from typing import (
@@ -234,11 +235,59 @@ def map_over_extended_structure(
     return [{k: func(v) for k, v in d.items()} for d in structure]
 
 
+def zip_extended_structures(
+    structure_a: list[dict[int, S]],
+    structure_b: list[dict[int, T]],
+) -> list[dict[int, Tuple[S, T]]]:
+    """Zip structures according to group id and sensor id.
+
+    Typical use case is reordering extended structures before iterating.
+
+    Example:
+
+        structure_a = [{1: a_1, 2: a_2}, {1: a_3}]
+
+        structure_b = [{1: b_1, 2: b_2}, {1: b_3}]
+
+        result: [{1: (a_1, b_1), 2: (a_2, b_2)}, 1: {(a_3, b_3)}]
+
+    """
+    res = []
+    try:
+        for group_id, sensor_id, value in iterate_extended_structure(structure_a):
+            res.append(
+                (
+                    group_id,
+                    sensor_id,
+                    (value, structure_b[group_id][sensor_id]),
+                ),
+            )
+    except (KeyError, IndexError):
+        raise ValueError("Structure of arguments are not the same.")
+
+    return create_extended_structure(iter(res))
+
+
 def zip3_extended_structures(
     structure_a: list[dict[int, S]],
     structure_b: list[dict[int, T]],
     structure_c: list[dict[int, U]],
 ) -> list[dict[int, Tuple[S, T, U]]]:
+    """Zip structures according to group id and sensor id.
+
+    Typical use case is reordering extended structures before iterating.
+
+    Example:
+
+        structure_a = [{1: a_1, 2: a_2}, {1: a_3}]
+
+        structure_b = [{1: b_1, 2: b_2}, {1: b_3}]
+
+        structure_c = [{1: c_1, 2: c_2}, {1: c_3}]
+
+        result: [{1: (a_1, b_1, c_1), 2: (a_2, b_2, c_2)}, {1: (a_3, b_3, c_3)}]
+
+    """
     res = []
     try:
         for group_id, sensor_id, value in iterate_extended_structure(structure_a):
@@ -268,6 +317,22 @@ def iterate_extended_structure(
             yield (group_id, sensor_id, elem)
 
 
+def iterate_extended_structure_as_entry_list(
+    structure: list[dict[int, ValueT]]
+) -> Iterator[Tuple[int, int, ValueT]]:
+    """Iterates over the elements of the extended structure.
+
+    Note: this differs from ``iterate_extended_structure`` as it returns the
+    ``entry_idx`` instead of the sensor id of a given entry.
+
+    :returns: Iterator of (<group idx>, <entry idx>, <element>)
+    """
+
+    for group_idx, group in enumerate(structure):
+        for entry_idx, elem in enumerate(group.values()):
+            yield (group_idx, entry_idx, elem)
+
+
 def extended_structure_entry_count(structure: list[dict[int, Any]]) -> int:
     """Traverses the extended structure and returns a count of all its entries
 
@@ -283,6 +348,30 @@ def iterate_extended_structure_values(structure: list[dict[int, ValueT]]) -> Ite
         yield value
 
 
+def extended_structure_shape(structure: list[dict[int, Any]]) -> list[set[int]]:
+    return [set(group.keys()) for group in structure]
+
+
+def transpose_extended_structures(
+    structures: list[list[dict[int, ValueT]]]
+) -> list[dict[int, list[ValueT]]]:
+    """'Transposes' a list of extended structures to create an extended structure of lists"""
+    shapes = [extended_structure_shape(s) for s in structures]
+    if not all(shape == shapes[0] for shape in shapes):
+        raise ValueError("All extended structures needs to have the same structure.")
+
+    product: list[dict[int, list[ValueT]]] = map_over_extended_structure(
+        lambda _: list(), structures[0]
+    )
+
+    for group_idx, sensor_id, value in itertools.chain(
+        *[iterate_extended_structure(es) for es in structures]
+    ):
+        product[group_idx][sensor_id].append(value)
+
+    return product
+
+
 def create_extended_structure(items: Iterator[Tuple[int, int, ValueT]]) -> list[dict[int, ValueT]]:
     structure: list[dict[int, ValueT]] = []
     current_group_index: Optional[int] = None
@@ -414,3 +503,6 @@ def indent_strs(strs: list[str], level: int) -> list[str]:
 
 
 attrs_ndarray_eq = attrs.cmp_using(eq=np.array_equal)  # type: ignore[call-arg]
+attrs_ndarray_isclose = attrs.cmp_using(
+    eq=lambda a, b: bool(np.isclose(a, b).all())
+)  # type: ignore[call-arg]
