@@ -283,7 +283,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
             self._started = False
             self.broadcast()
             self.callback(PluginStateMessage(state=PluginState.LOADED_IDLE))
-            self.callback(GeneralMessage(name="result_tick_time", data=None))
+            self.callback(GeneralMessage(name="rate_stats", data=None))
 
     def _get_next(self) -> None:
         if not self._started:
@@ -305,10 +305,8 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
             raise HandledException("Failed to get_next") from exc
 
-        _, _, some_service_result = next(
-            a121.iterate_extended_structure(result.service_extended_result)
-        )
-        self.callback(GeneralMessage(name="result_tick_time", data=some_service_result.tick_time))
+        assert self._client is not None
+        self.callback(GeneralMessage(name="rate_stats", data=self._client._rate_stats))
 
         self.callback(GeneralMessage(name="plot", data=result, recipient="plot_plugin"))
 
@@ -638,6 +636,12 @@ class ViewPlugin(DetectorViewPluginBase):
                 show_limit_values=False,
                 limit_texts=("Less power", "Higher quality"),
             ),
+            "update_rate": pidgets.OptionalFloatParameterWidgetFactory(
+                name_label_text="Update rate",
+                checkbox_label_text="Set",
+                limits=(1, None),
+                init_set_value=20,
+            ),
         }
 
     def on_app_model_update(self, app_model: AppModel) -> None:
