@@ -10,7 +10,8 @@ from ._enums import (
 )
 from ._exceptions import HandledException
 from .app import main
-from .app_model import AppModel, PlotPlugin, Plugin, ViewPlugin
+from .app_model import AppModel
 from .backend import BackendPlugin, GeneralMessage, Message, PluginStateMessage, is_task
+from .pluginbase import PlotPluginBase, PluginSpecBase, ViewPluginBase
 from .storage import get_temp_dir, get_temp_h5_path
 from .ui import BUTTON_ICON_COLOR
